Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9963)

Unified Diff: chrome/installer/util/delete_after_reboot_helper.h

Issue 392013: Correctly schedule empty parent directories for deletion when Chrome Frame is... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 11 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/installer/setup/uninstall.cc ('k') | chrome/installer/util/delete_after_reboot_helper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/util/delete_after_reboot_helper.h
===================================================================
--- chrome/installer/util/delete_after_reboot_helper.h (revision 31781)
+++ chrome/installer/util/delete_after_reboot_helper.h (working copy)
@@ -19,7 +19,10 @@
typedef std::pair<std::wstring, std::wstring> PendingMove;
-// Attempts to schedule the directory for deletion.
+// Attempts to schedule only the item at path for deletion.
+bool ScheduleFileSystemEntityForDeletion(const wchar_t* path);
+
+// Attempts to recursively schedule the directory for deletion.
bool ScheduleDirectoryForDeletion(const wchar_t* dir_name);
// Removes all pending moves that are registered for |directory| and all
« no previous file with comments | « chrome/installer/setup/uninstall.cc ('k') | chrome/installer/util/delete_after_reboot_helper.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698